import sys
from com.ibm.wbiserver.common.mbean import ComponentId
from java.util import ArrayList
from javax.management import ObjectName

def wsadminToList(inStr):
        outList=[]
        if (len(inStr)>0 and inStr[0]=='[' and inStr[-1]==']'):
                tmpList = inStr[1:-1].split(" ")
        else:
                tmpList = inStr.split("\n")  #splits for Windows or Linux
        for item in tmpList:
                item = item.rstrip();        #removes any Windows "\r"
                if (len(item)>0):
                        outList.append(item)
        return outList
#endDef

# BEGIN COPYRIGHT
# *************************************************************************
# Licensed Materials - Property of IBM 
# 5724-L01, 5655-N53, 5724-I82, 5655-R15
# (C) Copyright IBM Corporation 2005, 2006. All rights reserved. 
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
# *************************************************************************
# END COPYRIGHT
#
#  Export Selector Artifacts
#
#  This is a bi-modal script: it can be included in the wsadmin 
#  command invocation like this:
#     wsadmin -lang jython -f exportSelectorArtifacts.py http://test.po.selector PurchaseOrderSelector admin -zipf c:/artifacts/purchaseorder.zip
#  
#  or the script can be issued remotely using the wsadmin command line:
#     wsadmin -conntype SOAP 
#             -host gbhst6621
#             -lang jython 
#             -f exportSelectorArtifacts.py http://test.po.selector PurchaseOrderSelector admin -zipf c:/artifacts/purchaseorder.zip 
#             
#  The script expects some parameters:
#      arg1 - target namespace (e.g. http://test.po.selector)
#      arg2 - selector name (e.g. PurchaseOrderSelector)
#      arg3 - user (e.g. admin)
#     <arg4 - options>:
#             -zipf - name of a zip file to export the selector to (e.g. -zipf c:/artifacts/purchaseorder.zip). 
#              If not specified, it defaults to arg2.zip (e.g. PurchaseOrderSelector.zip) 
# 
#----------------------------------------------------------------------------------------------------------
#-------------------------------------------------------------------------------
#--- Error Exit codes.
#-------------------------------------------------------------------------------
COMPONENT_NOT_FOUND = 1
ARTIFACTS_NOT_FOUND = 2
USAGE_ERROR_CODE = 9

#-------------------------------------------------------------------------------
#--- Other constants
#-------------------------------------------------------------------------------
COMPONENT = "Selector"

#----------------------------------------------------------------------------------------------------------
# Internal switches:
#
# debugOutFlag   {1 = full debug trace output; 
#                 0 = no sysout output unless error and nlsEnabledFlag is off}
#
# nlsEnabledFlag {1 = NLS enabled, default, requires customization.jar to be present in <washome>\lib;
#                 0 = sysout will be used for errors}
#----------------------------------------------------------------------------------------------------------

# normally, it should be set to 0
debugOutFlag = 1

# set to 1, assumes message files are available
nlsEnabledFlag = 1

#-----------------------------------------------------------------
# Include common code:
# 
# exportArtifactsProc
#-----------------------------------------------------------------
global env
exportArtifactsProcFilePath = java.lang.System.getProperty("was.install.root") + "/bin/exportArtifactsProc.py"
execfile(exportArtifactsProcFilePath)
importArtifactsProcFilePath = java.lang.System.getProperty("was.install.root") + "/bin/importArtifactsProc.py"
execfile(importArtifactsProcFilePath)

#-------------------------------------------------------------
#-- Proc: printUsage 
#    prints globalized usage message
#-------------------------------------------------------------
def printUsage (  ):
        global nlsEnabledFlag
        if (nlsEnabledFlag == 1):
                printNLSText("CWSTM0020E", ["\nwsadmin -f exportSelectorArtifacts.jacl targetNamespace selectorName user \[-zipf zipFileName\]\nwsadmin  -conntype SOAP -host \[hostName\] -f exportSelectorArtifacts.jacl targetNamespace selectorName user \[-zipf zipFileName\]"] )
        else:
                print ""
                print ">>> Incorrect parameters given.  Usage: \nwsadmin -f exportSelectorArtifacts.jacl targetNamespace selectorName user [-zipf zipFileName]\n\nwsadmin -conntype SOAP -host [hostName] -f exportSelectorArtifacts.jacl  targetNamespace selectorName user [-zipf zipFileName]"
                print ""
        #endElse 
#endDef 

#-----------------------------------------------------------------
# Main
#-----------------------------------------------------------------

print " "
print "*********** exportSelectorArtifacts ---> ******"

if (len(sys.argv) < 3):
        printUsage( )
else:
        debugOut("***---> mainline" )

        targetNamespace = sys.argv[0]
        selectorName = sys.argv[1]
        userId = sys.argv[2]
        if (sys.argv[3] == "-zipf"):
                if (sys.argv[4] != ""):
                        exportZipf = sys.argv[4]
                else:
                        exportZipf = selectorName
                        exportZipf += ".zip"
                        debugOut("Defaulted ZIP file name to "+exportZipf )
                #endElse 
        else:
                exportZipf = selectorName
                exportZipf += ".zip"
                debugOut("Defaulted ZIP file name to "+exportZipf )
        #endElse 

        debugOut("Target namespace: "+targetNamespace )
        debugOut("Selector name: "+selectorName )
        debugOut("UserId: "+userId )
        debugOut("Export zip file: "+exportZipf )

        # get reference to SelectorMBean   
        mBean = AdminControl.completeObjectName("type=SelectorMBean,*" )
        mBeanObj = ObjectName( mBean ) 
        debugOut("MBean: "+mBean )

        componentId = ComponentId( targetNamespace, selectorName ) 
        componentIdList = ArrayList(  ) 
        # for now script exports just one selector
        componentIdList.add(0, componentId)
        # export artifacts 
        exportArtifacts(mBeanObj, componentIdList, userId, exportZipf )

        debugOut("***<--- mainline" )
        print " "
        print "****** <--- exportSelectorArtifacts ***********"
#endElse 

